@@ -1,6 +1,6 @@
 /***********************************************************************
 
-    $Id: mgc2mgc.c,v 1.1 1996/04/08 07:17:36 koishida Exp koishida $
+    $Id: _mgc2mgc.c,v 1.1.1.1 2000/03/01 13:58:42 yossie Exp $
 
     Frequency and Generalized Cepstral Transformation
 
@@ -24,31 +24,34 @@ void mgc2mgc(c1, m1, a1, g1, c2, m2, a2, g2)
 double *c1, *c2, a1, a2, g1, g2;
 int m1, m2;
 {
+    int           sub;
     double 	  a;
     static double *ca = NULL;
-    static int    size;
+    static int    size_a;
 
     if(ca == NULL){
-	ca = dgetmem(m2+1);
-	size = m2;
+	ca = dgetmem(m1+1);
+	size_a = m1;
     }
-    if(m2 > size){
+    if(m1 > size_a){
 	free(ca);
-	ca = dgetmem(m2+1);
-	size = m2;
+	ca = dgetmem(m1+1);
+	size_a = m1;
     }
 
     a = (a2 - a1) / (1 - a1*a2);
 
     if(a == 0){
 	movem(c1, ca, sizeof(*c1), m1+1);
-	fillz(ca+m1+1, sizeof(*ca), m2-m1);
+	gnorm(ca, ca, m1, g1);
+	gc2gc(ca, m1, g1, c2, m2, g2);
+	ignorm(c2, c2, m2, g2);
+    }
+    else{
+	freqt(c1, m1, c2, m2, a);
+	gnorm(c2, c2, m2, g1);
+	gc2gc(c2, m2, g1, c2, m2, g2);
+	ignorm(c2, c2, m2, g2);
     }
-    else
-	freqt(c1, m1, ca, m2, a);
-    
-    gnorm(ca, ca, m2, g1);
-    gc2gc(ca, m2, g1, c2, m2, g2);
-    ignorm(c2, c2, m2, g2);
 }
 
